# -*- coding: utf-8 -*-

"""Test Logos

Utilisation :
    créer les variables d'environnement: (indiquer les valeurs
    pour le serveur ScoDoc que vous voulez interroger)

    export SCODOC_URL="https://scodoc.xxx.net/"
    export SCODOC_USER="xxx"
    export SCODOC_PASSWD="xxx"
    export CHECK_CERTIFICATE=0 # ou 1 si serveur de production avec certif SSL valide

    (on peut aussi placer ces valeurs dans un fichier .env du répertoire tests/api).

    Lancer :
        pytest tests/api/test_api_partitions.py
"""

import requests

from tests.api.setup_test_api import SCODOC_URL, CHECK_CERTIFICATE, HEADERS
from tests.api.tools_test_api import verify_fields


# partition
def test_partition():
    fields = [
        "partition_id",
        "id",
        "formsemestre_id",
        "partition_name",
        "numero",
        "bul_show_rank",
        "show_in_lists",
    ]

    r = requests.get(
        SCODOC_URL + "/ScoDoc/api/partitions/1",
        headers=HEADERS,
        verify=CHECK_CERTIFICATE,
    )

    partition = r.json()[0]

    fields_OK = verify_fields(partition, fields)

    assert r.status_code == 200
    assert len(r.json()) == 2
    assert fields_OK is True


# etud_in_group
def test_etud_in_group():

    fields = [
        "etudid",
        "id",
        "dept_id",
        "nom",
        "prenom",
        "nom_usuel",
        "civilite",
        "date_naissance",
        "lieu_naissance",
        "dept_naissance",
        "nationalite",
        "statut",
        "boursier",
        "photo_filename",
        "code_nip",
        "code_ine",
        "scodoc7_id",
        "email",
        "emailperso",
        "domicile",
        "codepostaldomicile",
        "villedomicile",
        "paysdomicile",
        "telephone",
        "telephonemobile",
        "fax",
        "typeadresse",
        "description",
        "group_id",
        "etat",
        "civilite_str",
        "nom_disp",
        "nomprenom",
        "ne",
        "email_default",
    ]

    r = requests.get(
        SCODOC_URL + "/ScoDoc/api/partitions/groups/1",
        headers=HEADERS,
        verify=CHECK_CERTIFICATE,
    )

    etu = r.json()[0]

    fields_OK = verify_fields(etu, fields)

    assert r.status_code == 200
    assert len(r.json()) == 16
    assert fields_OK is True
    # r = requests.get(
    #     SCODOC_URL + "/ScoDoc/api/partitions/groups/1/etat/<string:etat>",
    #     headers=HEADERS,
    #     verify=CHECK_CERTIFICATE,
    # )
    # assert r.status_code == 200


# # set_groups
# def test_set_groups():
#     r = requests.get(
#         SCODOC_URL
#         + "/partitions/set_groups/partition/<int:partition_id>/groups/<string:groups_id>"
#           "/delete/<string:groups_to_delete>/create/<string:groups_to_create>",
#         headers=HEADERS,
#         verify=CHECK_CERTIFICATE,
#     )
#     assert r.status_code == 200
